@@ -37,8 +37,18 @@ namespace StOpt
 ///  The dimension with higher number of point is first split recursively
 /// \param  p_initDimension   number of meshes in each direction
 /// \param  p_bdimToSplit     for each dimension,  true if the dimension should be split
+/// \param  p_world           MPI communicator
 /// \return splitting of the grid in each dimension
-Eigen::ArrayXi paraOptimalSplitting(const Eigen::ArrayXi &p_initDimension, const Eigen::Array< bool, Eigen::Dynamic, 1> &p_bdimToSplit);
+Eigen::ArrayXi paraOptimalSplitting(const Eigen::ArrayXi &p_initDimension, const Eigen::Array< bool, Eigen::Dynamic, 1> &p_bdimToSplit, const boost::mpi::communicator &p_world);
+
+
+///  \brief Split the grid  and give the grid for a given processor
+/// \param p_grid             Give the current grid
+/// \param p_splittingRatio   For each dimension give the splitting ratio
+/// \param p_iProc            Processor number
+/// \param  p_world           MPI communicator
+/// \return splitting of the grid in each dimension
+Eigen::ArrayXi paraOptimalSplitting(const Eigen::ArrayXi &p_initDimension, const Eigen::Array< bool, Eigen::Dynamic, 1> &p_bdimToSplit, const boost::mpi::communicator &p_world);
 
 
 ///  \brief Split the grid  and give the grid for a given processor
@@ -61,6 +71,7 @@ private :
     Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, Eigen::Dynamic > m_meshPerProc ; ///<  For  each processor (column) , each stock number (row), store the meshes owned by the processor
     Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, Eigen::Dynamic > m_meshPerProcOldGrid ; ///<  For  each processor (column) , each stock number (row), store the meshes owned by the processor at previous iteration
 
+    boost::mpi::communicator m_world ; ///< MPI communicator
     // for current processor defines extended grid for all processors (GRID2)
     Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, Eigen::Dynamic >   m_extendGridProcOldGrid;
 
@@ -151,19 +162,18 @@ private :
                          const int &p_firstDimData,
                          std::vector< std::shared_ptr< Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic > > >    &p_tabReceiveFromOther)
     {
-        boost::mpi::communicator world;
         // Size of communicator
         int iRecSize = 0 ;
-        for (int iproc = 0 ; iproc < world.size() ; ++iproc)
+        for (int iproc = 0 ; iproc < m_world.size() ; ++iproc)
             if (iproc < static_cast<int>(p_bIntersecHCubeRecLoc.size()))
-                if ((p_bIntersecHCubeRecLoc[iproc]) && (iproc != world.rank())) iRecSize++;
+                if ((p_bIntersecHCubeRecLoc[iproc]) && (iproc != m_world.rank())) iRecSize++;
         std::vector<  boost::mpi::request > reqRec(iRecSize);
         int iRec = 0 ;
         // only one message right now (communication are not spread)
         for (int iproc = 0 ; iproc < static_cast<int>(p_bIntersecHCubeRecLoc.size()) ; ++iproc)
         {
             // receive
-            if ((p_bIntersecHCubeRecLoc[iproc]) && (iproc != world.rank()))
+            if ((p_bIntersecHCubeRecLoc[iproc]) && (iproc != m_world.rank()))
             {
                 // Number of mesh point associated
                 int nbPointRec = 1;
@@ -175,23 +185,23 @@ private :
                 // communication
                 int imesg_iproc = 0;
                 //   receive the data from  other processors
-                reqRec[iRec++] = world.irecv(iproc, imesg_iproc++, *p_tabReceiveFromOther[iproc]);
+                reqRec[iRec++] = m_world.irecv(iproc, imesg_iproc++, *p_tabReceiveFromOther[iproc]);
             }
         }
         // send
         // Array for sending to other processors
-        std::vector< std::shared_ptr< Eigen::Array< T,  Eigen::Dynamic, Eigen::Dynamic >  >  > tabSend(world.size());
+        std::vector< std::shared_ptr< Eigen::Array< T,  Eigen::Dynamic, Eigen::Dynamic >  >  > tabSend(m_world.size());
         int iSendSize = 0 ;
-        for (int iproc = 0 ; iproc < world.size() ; ++iproc)
+        for (int iproc = 0 ; iproc < m_world.size() ; ++iproc)
             if (iproc < static_cast<int>(p_bIntersecHCubeSendLoc.size()))
-                if ((p_bIntersecHCubeSendLoc[iproc]) && (iproc != world.rank())) iSendSize++ ;
+                if ((p_bIntersecHCubeSendLoc[iproc]) && (iproc != m_world.rank())) iSendSize++ ;
         std::vector<   boost::mpi::request > reqSend(iSendSize);
         int iSend = 0 ;
         for (int iproc = 0 ; iproc < static_cast<int>(p_bIntersecHCubeSendLoc.size()) ; ++iproc)
         {
-            if ((p_bIntersecHCubeSendLoc[iproc]) && (iproc != world.rank()))
+            if ((p_bIntersecHCubeSendLoc[iproc]) && (iproc != m_world.rank()))
             {
-                ParallelHiter hiter(p_gridToSendToProcessorLoc.col(iproc), m_meshPerProcOldGrid.col(world.rank()));
+                ParallelHiter hiter(p_gridToSendToProcessorLoc.col(iproc), m_meshPerProcOldGrid.col(m_world.rank()));
                 // - compute the number of data to send
                 int nbPointSend = hiter.hCubeSize();
                 tabSend[iproc] =  std::make_shared<Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic > >(p_firstDimData, nbPointSend);
@@ -208,7 +218,7 @@ private :
                 // send
                 int imesg_iproc = 0;
                 // Communications
-                reqSend[iSend++] =  world.isend(iproc, imesg_iproc++, * tabSend[iproc]);
+                reqSend[iSend++] =  m_world.isend(iproc, imesg_iproc++, * tabSend[iproc]);
             }
         }
         boost::mpi::wait_all(reqRec.begin(), reqRec.end());
@@ -257,10 +267,9 @@ private :
                          const  Eigen::Ref<const Eigen::Array< std::array<int, 2 >, Eigen::Dynamic, 1 > >        &p_gridTarget,
                          Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic >   &p_tabOwnedByProcessExtended)
     {
-        boost::mpi::communicator world;
         for (int iproc = 0 ; iproc <  static_cast<int>(p_bIntersecHCubeRecLoc.size()) ; ++iproc)
         {
-            if ((iproc != world.rank()) && (p_bIntersecHCubeRecLoc[iproc]))
+            if ((iproc != m_world.rank()) && (p_bIntersecHCubeRecLoc[iproc]))
             {
                 ParallelHiter hiter(p_gridComingFromProcessorLoc.col(iproc), p_gridTarget);
                 int segment = hiter.segmentSize();
@@ -283,9 +292,10 @@ public :
     /// \param p_initialDimension            Vector of number of points in each dimension
     /// \param p_gridCalcExt                 Permits to calculated extended grid for a given grid
     /// \param p_splittingRatio              For each dimension define how to split  the mesh
+    /// \param  p_world                      MPI communicator
     ParallelComputeGridSplitting(const Eigen::ArrayXi  &p_initialDimension,
                                  const std::function<  Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, 1 >(const Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, 1 > &) > &p_gridCalcExt,
-                                 const Eigen::ArrayXi  &p_splittingRatio);
+                                 const Eigen::ArrayXi  &p_splittingRatio, const boost::mpi::communicator &p_world);
 
     /// \brief Here constructor with GRID1, GRID2 and GRID3
     /// \param p_initialDimension                  Vector of grid discretization for GRID1
@@ -293,17 +303,19 @@ public :
     /// \param p_gridCalcExt                       Permits to calculated extended grid GRID2 from GRID1
     /// \param p_splittingRatio                    For each dimension define how to split  the mesh at the current step
     /// \param p_splittingRatioPrev                For each dimension define how to split  the mesh at the previous step
+    /// \param  p_world                      MPI communicator
     ParallelComputeGridSplitting(const Eigen::ArrayXi  &p_initialDimension, const  Eigen::ArrayXi  &p_initialDimensionPrev,
                                  const std::function<  Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, 1 >(const Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, 1 > &) > &p_gridCalcExt,
                                  const Eigen::ArrayXi   &p_splittingRatio,
-                                 const Eigen::ArrayXi   &p_splittingRatioPrev);
+                                 const Eigen::ArrayXi   &p_splittingRatioPrev, const boost::mpi::communicator &p_world);
 
     ///  \brief Last constructor used in simulation : no extended grid created
     ///  Only recalculate the repartition between processor of the grid
     /// \param p_initialDimension                Vector of the problem dimension
     /// \param p_splittingRatio                  For each dimension define how to split  the mesh so that prod( p_splittingRatio)
+    /// \param  p_world                      MPI communicator
     ParallelComputeGridSplitting(const Eigen::ArrayXi  &p_initialDimension,
-                                 const Eigen::ArrayXi  &p_splittingRatio);
+                                 const Eigen::ArrayXi  &p_splittingRatio, const boost::mpi::communicator &p_world);
 
     /// Get grid calculated by current processor
     Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, 1 >  getCurrentCalculationGrid() const;
@@ -330,26 +342,25 @@ public :
     Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic> runOneStep(const Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic>     &p_tabOwnedByProcess)
     {
 
-        boost::mpi::communicator world;
         // get row associated to returned array
         int firstDimSize = p_tabOwnedByProcess.rows();
-        boost::mpi::broadcast(world, firstDimSize, 0);
+        boost::mpi::broadcast(m_world, firstDimSize, 0);
         // allocate  new array
         Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic>  tabOwnedByProcessExtended(firstDimSize, m_iSizeExtendedArray);
         // Array to receive from other processors
-        std::vector< std::shared_ptr< Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic>  > > tabReceiveFromOther(world.size());
+        std::vector< std::shared_ptr< Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic>  > > tabReceiveFromOther(m_world.size());
         // routing achieved :
         paraRoutingExec<T>(m_bIntersecHCubeRec, m_bIntersecHCubeSend, m_gridComingFromProcessor, m_gridToSendToProcessor, p_tabOwnedByProcess, firstDimSize, tabReceiveFromOther);
         // use local mesh : if it has data to retrieve from its own data
-        if (world.rank() < static_cast<int>(m_bIntersecHCubeRec.size()))
-            if (m_bIntersecHCubeRec[world.rank()])
+        if (m_world.rank() < static_cast<int>(m_bIntersecHCubeRec.size()))
+            if (m_bIntersecHCubeRec[m_world.rank()])
             {
                 // now if necessary intersect the data with on the target grid
                 int isize  = 1 ;
                 for (size_t id = 0 ; id < m_nDim ; ++id)
-                    isize *= m_gridToSendToProcessor(id, world.rank())[1] - m_gridToSendToProcessor(id, world.rank())[0];
+                    isize *= m_gridToSendToProcessor(id, m_world.rank())[1] - m_gridToSendToProcessor(id, m_world.rank())[0];
                 Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic>  data(p_tabOwnedByProcess.rows(), isize);
-                ParallelHiter hiter(m_gridToSendToProcessor.col(world.rank()), m_meshPerProcOldGrid.col(world.rank()));
+                ParallelHiter hiter(m_gridToSendToProcessor.col(m_world.rank()), m_meshPerProcOldGrid.col(m_world.rank()));
                 int segment = hiter.segmentSize();
                 int iposStock = 0;
                 while (hiter.isValid())
@@ -359,10 +370,10 @@ public :
                     iposStock += segment;
                     hiter.next();
                 }
-                paraIntersecWithItself<T>(m_gridToSendToProcessor.col(world.rank()), data, firstDimSize, m_extendGridProcOldGrid.col(world.rank()), tabOwnedByProcessExtended);
+                paraIntersecWithItself<T>(m_gridToSendToProcessor.col(m_world.rank()), data, firstDimSize, m_extendGridProcOldGrid.col(m_world.rank()), tabOwnedByProcessExtended);
             }
         // get back to cash flow object all the data that where stored in tabReceiveFromOther
-        paraUnpackData<T>(tabReceiveFromOther, firstDimSize,  m_bIntersecHCubeRec,  m_gridComingFromProcessor, m_extendGridProcOldGrid.col(world.rank()), tabOwnedByProcessExtended);
+        paraUnpackData<T>(tabReceiveFromOther, firstDimSize,  m_bIntersecHCubeRec,  m_gridComingFromProcessor, m_extendGridProcOldGrid.col(m_world.rank()), tabOwnedByProcessExtended);
         return tabOwnedByProcessExtended;
     }
 
@@ -388,9 +399,8 @@ public :
             const Eigen::Array< std::array<int, 2 >, Eigen::Dynamic, 1 >   &p_gridOnProc0,
             int p_iReconsProc = 0)
     {
-        boost::mpi::communicator world;
         Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic > reconstructedArray;
-        if (world.rank() == p_iReconsProc)
+        if (m_world.rank() == p_iReconsProc)
         {
             int isizeRecons = 1 ;
             for (size_t id = 0 ; id < m_nDim; ++id)
@@ -401,7 +411,7 @@ public :
             reconstructedArray.resize(p_tabOwnedByProcess.rows(), isizeRecons);
         }
         // Array to receive from other processors
-        std::vector< std::shared_ptr< Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic > > > tabReceiveFromOther(world.size());
+        std::vector< std::shared_ptr< Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic > > > tabReceiveFromOther(m_world.size());
         // local array for intersection, receive,send localization
         std::vector<bool>  bIntersecHCubeRecLoc;
         std::vector<bool>   bIntersecHCubeSendLoc;
@@ -414,7 +424,7 @@ public :
         // routing achieved :
         paraRoutingExec<T>(bIntersecHCubeRecLoc, bIntersecHCubeSendLoc, gridComingFromProcessorLoc, gridToSendToProcessorLoc, p_tabOwnedByProcess, firstDimSize, tabReceiveFromOther);
         // only for processor p_ReconsProc
-        if (world.rank() == p_iReconsProc)
+        if (m_world.rank() == p_iReconsProc)
         {
             if (bIntersecHCubeRecLoc[p_iReconsProc])
             {
@@ -462,7 +472,6 @@ public :
     Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic >  reconstructAll(const Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic >   &p_tabOwnedByProcess,
             const  Eigen::Array< std::array<int, 2 >, Eigen::Dynamic, 1 > &p_gridOnProc)
     {
-        boost::mpi::communicator world;
         // to store all dimension needed by all processors
         std::vector<int>  DimPerProc;
         std::vector<int> DimCurrentProc(2 * m_nDim);
@@ -472,13 +481,13 @@ public :
             DimCurrentProc[id * 2 + 1] = p_gridOnProc(id)[1];
         }
         // mpi stuff
-        boost::mpi::all_gather<int>(world, DimCurrentProc.data(), 2 * m_nDim, DimPerProc);
+        boost::mpi::all_gather<int>(m_world, DimCurrentProc.data(), 2 * m_nDim, DimPerProc);
         // get size of first dimension (can be 0 for some processor)
         int nSizeFirstDim = 0;
-        boost::mpi::all_reduce(world, static_cast<int>(p_tabOwnedByProcess.rows()), nSizeFirstDim, boost::mpi::maximum<int>());
+        boost::mpi::all_reduce(m_world, static_cast<int>(p_tabOwnedByProcess.rows()), nSizeFirstDim, boost::mpi::maximum<int>());
         // calculated extended grid for each processor
-        Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, Eigen::Dynamic > extendedGridProcLoc(m_nDim, world.size());
-        for (int ip = 0; ip < world.size(); ++ip)
+        Eigen::Array<  std::array<int, 2 >, Eigen::Dynamic, Eigen::Dynamic > extendedGridProcLoc(m_nDim, m_world.size());
+        for (int ip = 0; ip < m_world.size(); ++ip)
             for (size_t id = 0 ; id < m_nDim; ++id)
             {
                 extendedGridProcLoc(id, ip)[0] = DimPerProc[ip * 2 * m_nDim +  id * 2];
@@ -487,7 +496,7 @@ public :
 
         int iSizeExtendedArrayLoc = 1;
         for (size_t id = 0 ; id < m_nDim; ++id)
-            iSizeExtendedArrayLoc *= extendedGridProcLoc(id, world.rank())[1] - extendedGridProcLoc(id, world.rank())[0];
+            iSizeExtendedArrayLoc *= extendedGridProcLoc(id, m_world.rank())[1] - extendedGridProcLoc(id, m_world.rank())[0];
         // allocate  new array
         Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic > reconstructedArray(nSizeFirstDim, iSizeExtendedArrayLoc);
         // array and vector needed locally ( add _loc to definition)
@@ -500,25 +509,25 @@ public :
         // store if sending data to other processor
         std::vector< bool>   bIntersecHCubeSendLoc;
         // routing plan to be effected
-        paraRoutingSchedule(extendedGridProcLoc, world.size(), bIntersecHCubeRecLoc, bIntersecHCubeSendLoc,
+        paraRoutingSchedule(extendedGridProcLoc, m_world.size(), bIntersecHCubeRecLoc, bIntersecHCubeSendLoc,
                             gridComingFromProcessorLoc, gridToSendToProcessorLoc);
         // Array to receive from other processors
-        std::vector< std::shared_ptr< Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic > > > tabReceiveFromOther(world.size());
+        std::vector< std::shared_ptr< Eigen::Array<T, Eigen::Dynamic, Eigen::Dynamic > > > tabReceiveFromOther(m_world.size());
         // routing achieved :
         paraRoutingExec<T>(bIntersecHCubeRecLoc, bIntersecHCubeSendLoc, gridComingFromProcessorLoc, gridToSendToProcessorLoc,
                            p_tabOwnedByProcess, nSizeFirstDim, tabReceiveFromOther);
         // use local mesh : if it has data to retrieve from its own data
-        if (world.rank() < static_cast<int>(bIntersecHCubeRecLoc.size()))
-            if (bIntersecHCubeRecLoc[world.rank()])
+        if (m_world.rank() < static_cast<int>(bIntersecHCubeRecLoc.size()))
+            if (bIntersecHCubeRecLoc[m_world.rank()])
             {
                 // first intersect data owned by processor 0 with p_gridOnProc
                 Eigen::Array< T, Eigen::Dynamic, Eigen::Dynamic > tabOwnedByProcessIntersec;
                 Eigen::Array< std::array< int, 2 >, Eigen::Dynamic, 1 > gridIntersected(m_nDim);
-                paraIntersecDataHyperCube<T>(p_tabOwnedByProcess,  m_meshPerProc.col(world.rank()), p_gridOnProc, tabOwnedByProcessIntersec, nSizeFirstDim, gridIntersected);
+                paraIntersecDataHyperCube<T>(p_tabOwnedByProcess,  m_meshPerProc.col(m_world.rank()), p_gridOnProc, tabOwnedByProcessIntersec, nSizeFirstDim, gridIntersected);
                 paraIntersecWithItself<T>(gridIntersected, tabOwnedByProcessIntersec, nSizeFirstDim, p_gridOnProc, reconstructedArray);
             }
         // get back to cash flow objet all the data that where stored in tabReceiveFromOther
-        paraUnpackData<T>(tabReceiveFromOther, nSizeFirstDim, bIntersecHCubeRecLoc,  gridComingFromProcessorLoc, extendedGridProcLoc.col(world.rank()), reconstructedArray);
+        paraUnpackData<T>(tabReceiveFromOther, nSizeFirstDim, bIntersecHCubeRecLoc,  gridComingFromProcessorLoc, extendedGridProcLoc.col(m_world.rank()), reconstructedArray);
 
         return reconstructedArray;
     }
