@@ -18,6 +18,7 @@
 #include "StOpt/core/grids/SpaceGrid.h"
 #include "StOpt/core/grids/FullGrid.h"
 #include "StOpt/core/utils/Polynomials1D.h"
+#include "StOpt/core/utils/version.h"
 #include "StOpt/regression/LocalLinearRegression.h"
 #include "StOpt/regression/LocalConstRegression.h"
 #include "StOpt/regression/LocalSameSizeLinearRegression.h"
@@ -31,7 +32,9 @@
 #include "StOpt/regression/LaplacianGridKernelRegression.h"
 #include "StOpt/regression/SparseRegression.h"
 #include "StOpt/regression/GlobalRegression.h"
+#include "StOpt/regression/ContinuationValueBase.h"
 #include "StOpt/regression/ContinuationValue.h"
+#include "StOpt/regression/ContinuationValueDet.h"
 #include "StOpt/regression/ContinuationCuts.h"
 #include "StOpt/regression/GridAndRegressedValueGeners.h"
 
@@ -121,6 +124,9 @@ public :
 /// \brief Encapsulation for regression module
 PYBIND11_MODULE(StOptReg, m)
 {
+    // version
+    m.def("getVersion", StOpt::getStOptVersion);
+
     // Map regressors
     //****************
     py::class_<StOpt::BaseRegression, std::shared_ptr<StOpt::BaseRegression>, PyBaseRegression>(m, "BaseRegression")
@@ -289,6 +295,17 @@ PYBIND11_MODULE(StOptReg, m)
     .def("getParticles", &StOpt::ContinuationValue::getParticles)
     ;
 
+    py::class_<StOpt::ContinuationValueDet, std::shared_ptr<StOpt::ContinuationValueDet> >(m, "ContinuationValueDet")
+    .def(py::init <  const std::shared_ptr< StOpt::SpaceGrid >  &,  const Eigen::ArrayXXd & > ())
+    .def("loadForSimulation", &StOpt::ContinuationValueDet::loadForSimulation)
+    .def("getAllSimulations", (Eigen::ArrayXd(StOpt::ContinuationValueDet::*)(const Eigen::ArrayXd &) const) &StOpt::ContinuationValueDet::getAllSimulations)
+    .def("getAllSimulations", (Eigen::ArrayXd(StOpt::ContinuationValueDet::*)(const StOpt::Interpolator &) const) &StOpt::ContinuationValueDet::getAllSimulations)
+    .def("getASimulation", (double (StOpt::ContinuationValueDet::*)(const int &, const StOpt::Interpolator &) const)  &StOpt::ContinuationValueDet::getASimulation, "From interpolator")
+    .def("getValues", &StOpt::ContinuationValueDet::getValuesCopy)
+    .def("getGrid", &StOpt::ContinuationValueDet::getGrid)
+    .def("getNbSimul", &StOpt::ContinuationValueDet::getNbSimul)
+    ;
+
     // map grid and regressed values
     py::class_<StOpt::GridAndRegressedValue, std::shared_ptr<StOpt::GridAndRegressedValue> >(m, "GridAndRegressedValue")
     .def(py::init <  const std::shared_ptr< StOpt::SpaceGrid >  &,  const std::shared_ptr< StOpt::BaseRegression> &,    const Eigen::ArrayXXd & > ())
