@@ -1,8 +1,8 @@
 // Copyright (C) 2016 EDF
 // All Rights Reserved
 // This code is published under the GNU Lesser General Public License (GNU LGPL)
-#ifndef SIMULATEREGREGRESSIONDIST_H
-#define SIMULATEREGREGRESSIONDIST_H
+#ifndef SIMULATEREGRESSIONDIST_H
+#define SIMULATEREGRESSIONDIST_H
 #include <functional>
 #include <memory>
 #include <Eigen/Dense>
