@@ -1,14 +1,12 @@
-#define BOOST_TEST_MODULE StOptRegularSpaceGrid
-
+#define BOOST_TEST_MODULE RegularSpaceGrid
+#define BOOST_TEST_DYN_LINK
 #include <iomanip>
 #include <boost/test/unit_test.hpp>
-#include <boost/log/trivial.hpp>
-#include <boost/format.hpp>
-using boost::format;
-
 #include "StOpt/core/grids/RegularSpaceGrid.h"
 #include "StOpt/core/utils/constant.h"
 
+using namespace std;
+
 BOOST_AUTO_TEST_CASE(StOptRegularSpaceGrid)
 {
     size_t nsteps = 1000;
@@ -33,14 +31,14 @@ BOOST_AUTO_TEST_CASE(StOptRegularSpaceGrid)
 
     std::stringstream ss_minimum;
     ss_minimum << std::fixed << std::setprecision(15) << minimum(0);
-    BOOST_LOG_TRIVIAL(info) << "minimum: " << ss_minimum.str();
+    cout  << "minimum: " << ss_minimum.str();
     std::stringstream ss_point;
     ss_point << std::fixed << std::setprecision(15) << point(0);
-    BOOST_LOG_TRIVIAL(info) << "point: " << ss_point.str();
-    BOOST_LOG_TRIVIAL(info) << "grid.isInside(point): " << grid.isInside(point);
+    cout  << "point: " << ss_point.str();
+    cout  << "grid.isInside(point): " << grid.isInside(point);
     if (grid.isInside(point))
     {
         Eigen::ArrayXi result = grid.lowerPositionCoord(point); // Assertion fails.
-        BOOST_LOG_TRIVIAL(info) << "grid.lowerPositionCoord(point): " << result;
+        cout << "grid.lowerPositionCoord(point): " << result;
     }
 }
