@@ -471,11 +471,12 @@ void testDimensionFonctionality1DOnGrid(const bool &p_bLin,  const int &p_nbSimu
     }
     // archive
     {
-        BinaryFileArchive ar("archive", "w");
+        BinaryFileArchive ar("archiveLGKR", "w");
         ar << Record(kernelReg, "Regressor", "Top") ;
+        ar.flush();
     }
     {
-        BinaryFileArchive ar("archive", "r");
+        BinaryFileArchive ar("archiveLGKR", "r");
         LaplacianGridKernelRegression regAr;
         Reference<LaplacianGridKernelRegression> (ar, "Regressor", "Top").restore(0, &regAr);
         for (int is = 0; is < p_nbSimul / 10; ++is)
@@ -544,11 +545,12 @@ void testDimensionFonctionality2DOnGrid(const bool &p_bLin,  const int &p_nbSimu
     }
     // archive
     {
-        BinaryFileArchive ar("archive", "w");
+        BinaryFileArchive ar("archiveLGKR1", "w");
         ar << Record(kernelReg, "Regressor", "Top") ;
+        ar.flush();
     }
     {
-        BinaryFileArchive ar("archive", "r");
+        BinaryFileArchive ar("archiveLGKR1", "r");
         LaplacianGridKernelRegression regAr;
         Reference<LaplacianGridKernelRegression> (ar, "Regressor", "Top").restore(0, &regAr);
         for (int is = 0; is < p_nbSimul / 10; ++is)
@@ -633,13 +635,13 @@ void TestContinuationValue(const bool &p_bLin, const int &p_nDim,  const int &p_
             BOOST_CHECK_CLOSE(regressedByContinuation(is), regressedByContinuationSecond(is), p_accuracyInterp);
         }
         // default non compression
-        BinaryFileArchive ar("archive", "w");
+        BinaryFileArchive ar("archiveLGKR2", "w");
         ar << Record(continuation, "FirstContinuation", "Top") ;
 
     }
     {
         // read archive
-        BinaryFileArchive ar("archive", "r");
+        BinaryFileArchive ar("archiveLGKR2", "r");
         ContinuationValue contRead;
         Reference< ContinuationValue >(ar, "FirstContinuation", "Top").restore(0, &contRead);
         ArrayXd ptStock(1) ;
